@@ -20,8 +20,9 @@ const DEFAULT_RDR_BUFFER_CAPACITY: usize = 16 * (1 << 10);
 pub const DEFAULT_WTR_BUFFER_CAPACITY: usize = 64 * (1 << 10);
 // number of rows for csv_sniffer to sample
 const DEFAULT_SNIFFER_SAMPLE: usize = 200;
-// number of bytes to check for UTF8 encoding
+// for files, number of bytes to check for UTF8 encoding
 const DEFAULT_UTF8_CHECK_BUFFER_LEN: usize = 8192;
+const UTF8_ERROR_MSG: &str = "is not UTF-8 encoded. Use the input command to transcode to UTF-8.";
 
 #[derive(Clone, Copy, Debug)]
 pub struct Delimiter(pub u8);
@@ -80,6 +81,7 @@ pub struct Config {
     double_quote: bool,
     escape: Option<u8>,
     quoting: bool,
+    trim: csv::Trim,
     autoindex: bool,
     checkutf8: bool,
 }
@@ -143,6 +145,7 @@ impl Config {
             double_quote: true,
             escape: None,
             quoting: true,
+            trim: csv::Trim::None,
             autoindex: env::var("QSV_AUTOINDEX").is_ok(),
             checkutf8: env::var("QSV_SKIPUTF8_CHECK").is_err(),
         }
@@ -216,6 +219,11 @@ impl Config {
         self
     }
 
+    pub fn trim(mut self, trim_type: csv::Trim) -> Config {
+        self.trim = trim_type;
+        self
+    }
+
     pub fn select(mut self, sel_cols: SelectColumns) -> Config {
         self.select_columns = Some(sel_cols);
         self
@@ -225,6 +233,11 @@ impl Config {
         self.path.is_none()
     }
 
+    pub fn checkutf8(mut self, yes: bool) -> Config {
+        self.checkutf8 = yes;
+        self
+    }
+
     pub fn selection(&self, first_record: &csv::ByteRecord) -> Result<Selection, String> {
         match self.select_columns {
             None => Err("Config has no 'SelectColums'. Did you call \
@@ -266,7 +279,7 @@ impl Config {
                 if !self.is_utf8_encoded() {
                     return Err(io::Error::new(
                         io::ErrorKind::InvalidData,
-                        format!("{p:?} is not UTF8 encoded."),
+                        format!("{p:?} {UTF8_ERROR_MSG}"),
                     ));
                 }
                 fs::File::open(p).map(|f| self.from_reader(f))
@@ -274,24 +287,6 @@ impl Config {
         }
     }
 
-    // pub fn get_file_path(&self) -> String {
-    //     match self.path {
-    //         None => Err(io::Error::new(
-    //             io::ErrorKind::InvalidInput,
-    //             "Cannot use <stdin> here",
-    //         )),
-    //         Some(ref p) => {
-    //             if !self.is_utf8_encoded() {
-    //                 return Err(io::Error::new(
-    //                     io::ErrorKind::InvalidData,
-    //                     format!("{p:?} is not UTF8 encoded."),
-    //                 ));
-    //             }
-    //             fs::File::open(p).map(|f| self.from_reader(f))
-    //         }
-    //     }
-    // }
-
     pub fn reader_file_stdin(&self) -> io::Result<csv::Reader<Box<dyn SeekRead + 'static>>> {
         Ok(match self.path {
             None => {
@@ -301,12 +296,12 @@ impl Config {
                 stdin.lock().read_to_end(&mut buffer)?;
                 // check if its utf8-encoded
                 if self.checkutf8 {
-                    let s = String::from_utf8_lossy(&buffer);
                     debug!("checking stdin encoding...");
-                    if s.contains(std::char::REPLACEMENT_CHARACTER) {
+                    let s = std::str::from_utf8(&buffer);
+                    if s.is_err() {
                         return Err(io::Error::new(
                             io::ErrorKind::InvalidData,
-                            "<stdin> is not UTF8 encoded.",
+                            format!("<stdin> {UTF8_ERROR_MSG}"),
                         ));
                     }
                 }
@@ -316,7 +311,7 @@ impl Config {
                 if !self.is_utf8_encoded() {
                     return Err(io::Error::new(
                         io::ErrorKind::InvalidData,
-                        format!("{p:?} is not UTF8 encoded."),
+                        format!("{p:?} {UTF8_ERROR_MSG}"),
                     ));
                 }
                 self.from_reader(Box::new(fs::File::open(p).unwrap()))
@@ -341,8 +336,8 @@ impl Config {
             }
             let mut buffer = vec![0; buffer_size];
             if f.read_exact(&mut buffer).is_ok() {
-                let s = String::from_utf8_lossy(&buffer);
-                return !s.contains(std::char::REPLACEMENT_CHARACTER);
+                let s = std::str::from_utf8(&buffer);
+                return s.is_ok();
             }
         }
         false
@@ -421,12 +416,11 @@ impl Config {
                     let mut buffer: Vec<u8> = Vec::new();
                     stdin_reader.lock().read_to_end(&mut buffer)?;
                     // check if its utf8-encoded
-                    let s = String::from_utf8_lossy(&buffer);
-                    debug!("checking stdin encoding...");
-                    if s.contains(std::char::REPLACEMENT_CHARACTER) {
+                    let s = std::str::from_utf8(&buffer);
+                    if s.is_err() {
                         return Err(io::Error::new(
                             io::ErrorKind::InvalidData,
-                            "<stdin> is not UTF8 encoded.",
+                            format!("<stdin> {UTF8_ERROR_MSG}"),
                         ));
                     }
                     Box::new(io::Cursor::new(buffer))
@@ -438,7 +432,7 @@ impl Config {
                 if !self.is_utf8_encoded() {
                     return Err(io::Error::new(
                         io::ErrorKind::InvalidData,
-                        format!("{p:?} is not UTF8 encoded."),
+                        format!("{p:?} {UTF8_ERROR_MSG}"),
                     ));
                 }
                 match fs::File::open(p) {
@@ -471,6 +465,7 @@ impl Config {
             .escape(self.escape)
             .buffer_capacity(rdr_buffer)
             .comment(rdr_comment)
+            .trim(self.trim)
             .from_reader(rdr)
     }
 
